@@ -62,20 +62,6 @@ function(input, output, session) {
   setting_figures$width <- 8
   setting_figures$dpi <- 600
 
-  # %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-  # COUNTER ####
-  # %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-  output$counter <- renderText({
-    if (!file.exists("counter.Rdata")) {
-      counter <- 0
-    } else {
-      load(file = "counter.Rdata")
-    }
-    counter <- counter + 1
-    save(counter, file = "counter.Rdata")
-    paste0("Hits:", counter)
-  })
 
   # %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   # DATA PAGE ####
@@ -143,12 +129,20 @@ function(input, output, session) {
 
   source("server/Setting.R", local = TRUE)
 
-
   # url resolver
   observe({
     query <- parseQueryString(session$clientData$url_search)
-    if (!is.null(names(query)) && names(query) == "print_version") {
-      session$sendCustomMessage("sessinf", sessionInfo())
+    if (!is.null(names(query)) && names(query) == "session_info") {
+      session$sendCustomMessage("send_to_console", sessionInfo())
     }
   })
+
+  # visitor counter - dont use if not served by shiny-server that
+  # has the counter in the parent directory
+  if (file.exists("../visitor_counter.txt")) {
+  count <- as.integer(readLines("../visitor_counter.txt", n = 1L))
+  session$sendCustomMessage("updateCounter", format(count, big.mark = ","))
+  count <- count + 1L
+  writeLines(as.character(count), "../visitor_counter.txt")
+  }
 }
